import './vendors/bootstrap/bootstrap-datatable'
import './vendors/asap/ASAP'
import './vendors/bootstrap/bootstrap-slider'
import './vendors/bootstrap/bootstrap3-typeahead'
import './vendors/bootstrap/validator'
import './vendors/html5/html5shiv'
import './vendors/gauge.coffee/gauge'
import './vendors/jquery/jquery.tablesorter'

import './vendors/bootstrap-select/bootstrap-select'

/* Todo: remove nvd3 from here, too huge non minified */
import nv from './vendors/nvd3/nv.d3'
import Tagify from './vendors/tagify/tagify.min.js'

import './vendors/datatables/datatable-ipsorting'
import './vendors/datatables/datatable-macsorting'
import './vendors/datatables/datatable-colvisibility'

import './vendors/dygraphs/canvas';

window.nv = nv
window.Tagify = Tagify
